@@ -1,7 +1,7 @@
 #' @export
 standard_error.bayesx <- function(model, ...) {
   .data_frame(
-    Parameter = find_parameters(model, component = "conditional", flatten = TRUE),
+    Parameter = insight::find_parameters(model, component = "conditional", flatten = TRUE),
     SE = model$fixed.effects[, 2]
   )
 }
@@ -16,7 +16,7 @@ ci.bayesx <- function(x, ci = .95, ...) {
 #' @export
 p_value.bayesx <- function(model, ...) {
   .data_frame(
-    Parameter = find_parameters(model, component = "conditional", flatten = TRUE),
+    Parameter = insight::find_parameters(model, component = "conditional", flatten = TRUE),
     p = model$fixed.effects[, 4]
   )
 }
