@@ -4,8 +4,6 @@
 # model_parameters -----
 
 
-#' @importFrom stats coef
-#' @importFrom utils modifyList
 #' @inheritParams simulate_model
 #' @rdname model_parameters.merMod
 #' @export
@@ -13,16 +11,16 @@ model_parameters.glmmTMB <- function(model,
                                      ci = .95,
                                      bootstrap = FALSE,
                                      iterations = 1000,
-                                     effects = "fixed", ## TODO change to "all" after effectsize > 0.4.4-1 on CRAN
+                                     effects = "all",
                                      component = "all",
                                      group_level = FALSE,
                                      standardize = NULL,
                                      exponentiate = FALSE,
                                      df_method = NULL,
-                                     details = FALSE,
                                      p_adjust = NULL,
                                      wb_component = TRUE,
                                      summary = FALSE,
+                                     parameters = NULL,
                                      verbose = TRUE,
                                      ...) {
   # p-values, CI and se might be based on different df-methods
@@ -34,11 +32,10 @@ model_parameters.glmmTMB <- function(model,
 
   # standardize only works for fixed effects...
   if (!is.null(standardize)) {
+    if (!missing(effects) && effects != "fixed" && verbose) {
+      warning(insight::format_message("Standardizing coefficients only works for fixed effects of the mixed model."), call. = FALSE)
+    }
     effects <- "fixed"
-    ## TODO enable later, when fixed in "effectsize"
-    # if (verbose) {
-    #   warning("Standardizing coefficients only works for fixed effects of the mixed model.", call. = FALSE)
-    # }
   }
 
   # fix argument, if model has only conditional component
@@ -64,7 +61,7 @@ model_parameters.glmmTMB <- function(model,
       if (effects != "fixed") {
         effects <- "fixed"
         if (verbose) {
-          warning("Bootstrapping only returns fixed effects of the mixed model.", call. = FALSE)
+          warning(insight::format_message("Bootstrapping only returns fixed effects of the mixed model."), call. = FALSE)
         }
       }
     } else {
@@ -77,6 +74,7 @@ model_parameters.glmmTMB <- function(model,
         df_method = df_method,
         p_adjust = p_adjust,
         wb_component = wb_component,
+        filter_parameters = NULL,
         keep_component_column = component != "conditional",
         ...
       )
@@ -133,6 +131,12 @@ model_parameters.glmmTMB <- function(model,
     params$Level <- NULL
   }
 
+  # filter parameters
+  if (!is.null(parameters)) {
+    params <- .filter_parameters(params, parameters, verbose = verbose)
+  }
+
+
   # due to rbind(), we lose attributes from "extract_parameters()",
   # so we add those attributes back here...
   if (!is.null(att)) {
@@ -152,15 +156,6 @@ model_parameters.glmmTMB <- function(model,
     ...
   )
 
-
-  ## TODO remove in a future update
-  if (isTRUE(details)) {
-    attr(params, "details") <- .randomeffects_summary(model)
-    if (verbose) {
-      message("Argument 'details' is deprecated. Please use 'group_level'.")
-    }
-  }
-
   attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
@@ -263,8 +258,6 @@ standard_error.glmmTMB <- function(model,
 # p_value -----
 
 
-#' @importFrom insight find_parameters
-#' @importFrom stats coef
 #' @rdname p_value.lmerMod
 #' @export
 p_value.glmmTMB <- function(model, component = c("all", "conditional", "zi", "zero_inflated", "dispersion"), verbose = TRUE, ...) {
@@ -296,8 +289,6 @@ p_value.glmmTMB <- function(model, component = c("all", "conditional", "zi", "ze
 # simulate model -----
 
 
-#' @importFrom stats vcov setNames
-#' @importFrom insight get_parameters
 #' @rdname simulate_model
 #' @export
 simulate_model.glmmTMB <- function(model, iterations = 1000, component = c("all", "conditional", "zi", "zero_inflated", "dispersion"), verbose = FALSE, ...) {
