@@ -1,20 +1,36 @@
+## from rms / rmsb package
+
+
+# model parameters -------------
+
+
+#' @export
+model_parameters.blrm <- model_parameters.bayesQR
+
+
+
+
+# ci -------------
+
 
 #' @export
 ci.lrm <- ci.tobit
 
-
 #' @export
 ci.psm <- ci.tobit
 
-
 #' @export
 ci.ols <- ci.tobit
 
-
 #' @export
 ci.rms <- ci.tobit
 
 
+
+
+# standard error -------------
+
+
 #' @export
 standard_error.lrm <- function(model, ...) {
   se <- sqrt(diag(stats::vcov(model)))
@@ -28,19 +44,20 @@ standard_error.lrm <- function(model, ...) {
   )
 }
 
-
 #' @export
 standard_error.ols <- standard_error.lrm
 
-
 #' @export
 standard_error.rms <- standard_error.lrm
 
-
 #' @export
 standard_error.psm <- standard_error.lrm
 
 
+
+
+# p-values -----------------------
+
 #' @export
 p_value.lrm <- function(model, ...) {
   stat <- insight::get_statistic(model)
@@ -52,14 +69,14 @@ p_value.lrm <- function(model, ...) {
   )
 }
 
-
 #' @export
 p_value.ols <- p_value.lrm
 
-
 #' @export
 p_value.rms <- p_value.lrm
 
-
 #' @export
 p_value.psm <- p_value.lrm
+
+#' @export
+p_value.blrm <- p_value.BFBayesFactor
