@@ -3,23 +3,21 @@
 #' @export
 model_parameters.mixor <- function(model,
                                    ci = .95,
-                                   effects = "fixed", ## TODO change to "all" after effectsize > 0.4.4-1 on CRAN
+                                   effects = "all",
                                    bootstrap = FALSE,
                                    iterations = 1000,
                                    standardize = NULL,
                                    exponentiate = FALSE,
-                                   details = FALSE,
                                    verbose = TRUE,
                                    ...) {
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
 
   # standardize only works for fixed effects...
   if (!is.null(standardize)) {
+    if (!missing(effects) && effects != "fixed" && verbose) {
+      warning(insight::format_message("Standardizing coefficients only works for fixed effects of the mixed model."), call. = FALSE)
+    }
     effects <- "fixed"
-    ## TODO enable later, when fixed in "effectsize"
-    # if (verbose) {
-    #   warning("Standardizing coefficients only works for fixed effects of the mixed model.", call. = FALSE)
-    # }
   }
 
   out <- .model_parameters_generic(
@@ -37,10 +35,6 @@ model_parameters.mixor <- function(model,
 
   attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
 
-  if (isTRUE(details)) {
-    attr(out, "details") <- .randomeffects_summary(model)
-  }
-
   out
 }
 
@@ -54,7 +48,6 @@ ci.mixor <- function(x, ci = .95, effects = "all", ...) {
 
 
 #' @rdname standard_error
-#' @importFrom insight get_parameters
 #' @export
 standard_error.mixor <- function(model, effects = "all", ...) {
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
@@ -70,7 +63,6 @@ standard_error.mixor <- function(model, effects = "all", ...) {
 
 
 #' @rdname p_value.lmerMod
-#' @importFrom insight get_parameters
 #' @export
 p_value.mixor <- function(model, effects = "all", ...) {
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
