@@ -5,6 +5,7 @@ model_parameters.mjoint <- function(model,
                                     component = c("all", "conditional", "survival"),
                                     exponentiate = FALSE,
                                     p_adjust = NULL,
+                                    parameters = NULL,
                                     verbose = TRUE,
                                     ...) {
   effects <- match.arg(effects, choices = c("fixed", "random", "all"))
@@ -22,6 +23,7 @@ model_parameters.mjoint <- function(model,
       robust = FALSE,
       df_method = NULL,
       p_adjust = p_adjust,
+      filter_parameters = parameters,
       ...
     )
 
