@@ -12,6 +12,7 @@ model_parameters.stanfit <- function(model,
                                      exponentiate = FALSE,
                                      standardize = NULL,
                                      group_level = FALSE,
+                                     parameters = NULL,
                                      verbose = TRUE,
                                      ...) {
 
@@ -30,6 +31,7 @@ model_parameters.stanfit <- function(model,
     priors = FALSE,
     effects = effects,
     standardize = standardize,
+    filter_parameters = parameters,
     verbose = verbose,
     ...
   )
