@@ -113,7 +113,6 @@ n_clusters <- function(x,
 }
 
 
-#' @importFrom utils capture.output
 #' @keywords internal
 .n_clusters_cluster <- function(x, ...) {
   if (!requireNamespace("cluster", quietly = TRUE)) {
@@ -124,7 +123,7 @@ n_clusters <- function(x,
   x <- stats::na.omit(x)
 
   # Gap Statistic for Estimating the Number of Clusters
-  junk <- utils::capture.output(gap <- cluster::clusGap(x, kmeans, K.max = 10, B = 100)$Tab)
+  junk <- utils::capture.output(gap <- cluster::clusGap(x, stats::kmeans, K.max = 10, B = 100)$Tab)
 
   # Gap Statistic for Estimating the Number of Clusters
   n <- cluster::maxSE(
@@ -139,7 +138,6 @@ n_clusters <- function(x,
 
 
 
-#' @importFrom grDevices png dev.off
 #' @keywords internal
 .n_clusters_NbClust <- function(x, fast = TRUE, ...) {
   if (!requireNamespace("NbClust", quietly = TRUE)) {
