@@ -18,8 +18,23 @@ print_html.parameters_model <- function(x,
                                         show_sigma = FALSE,
                                         show_formula = FALSE,
                                         zap_small = FALSE,
+                                        groups = NULL,
                                         verbose = TRUE,
                                         ...) {
+  # check if user supplied digits attributes
+  if (missing(digits)) {
+    digits <- .additional_arguments(x, "digits", digits)
+  }
+  if (missing(ci_digits)) {
+    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+  }
+  if (missing(p_digits)) {
+    p_digits <- .additional_arguments(x, "p_digits", p_digits)
+  }
+  if (missing(footer_digits)) {
+    footer_digits <- .additional_arguments(x, "footer_digits", footer_digits)
+  }
+
   # table caption
   table_caption <- .print_caption(x, caption, format = "html")
 
@@ -36,6 +51,7 @@ print_html.parameters_model <- function(x,
     ci_width = NULL,
     ci_brackets = ci_brackets,
     format = "html",
+    groups = groups,
     ...
   )
 
@@ -81,6 +97,17 @@ print_html.compare_parameters <- function(x,
   # save original input
   orig_x <- x
 
+  # check if user supplied digits attributes
+  if (missing(digits)) {
+    digits <- .additional_arguments(x, "digits", digits)
+  }
+  if (missing(ci_digits)) {
+    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+  }
+  if (missing(p_digits)) {
+    p_digits <- .additional_arguments(x, "p_digits", p_digits)
+  }
+
   # get attributes
   if (missing(style) || is.null(style)) {
     style <- attributes(x)$output_style
