@@ -20,8 +20,10 @@ if (require("testthat") && require("insight") && require("parameters") && requir
     expect_equal(params$SE, c(6.82452, 1.54578, NA, NA, NA, NA), tolerance = 1e-3)
     expect_equal(
       colnames(params),
-      c("Parameter", "Coefficient", "SE", "CI", "CI_low", "CI_high", "t",
-        "df_error", "p", "Effects", "Group")
+      c(
+        "Parameter", "Coefficient", "SE", "CI", "CI_low", "CI_high", "t",
+        "df_error", "p", "Effects", "Group"
+      )
     )
   })
 }
